@@ -2,7 +2,7 @@ package ENV::Util;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub import {
     my ($pkg, $cmd, @args) = @_;
@@ -36,13 +36,16 @@ sub load_dotenv {
     my @lines;
     { local $!; @lines = <$fh> }
     my %env;
+    # POSIX convention for env variable names:
+    my $varname_re = qr/[a-zA-Z_][a-zA-Z0-9_]+/;
     foreach my $line (@lines) {
         # code heavily inspired by Dotenv.pm (BooK++)
         if (my ($k, $v) = $line =~ m{
             \A\s*
-            (?: export \s+ )?           # the 'export' keyword is optional
-            ( [a-zA-Z_][a-zA-Z0-9_]+ )  # POSIX convention for env variable names
-            (?: \s* = \s* )
+            # 'export' (bash), 'set'/'setenv' ([t]csh) are optional keywords:
+            (?: (?:export|set|setenv) \s+ )?
+            ( $varname_re )
+            (?: \s* (?:=|\s+) \s* )       # separator is '=' or spaces
             (
               '[^']*(?:\\'|[^']*)*'  # single quoted value
              |"[^"]*(?:\\"|[^"]*)*"  # or double quoted value
@@ -54,10 +57,23 @@ sub load_dotenv {
             $v = '' unless defined $v;
             $v =~ s/\s*\z//;
 
-            # single and double quotes semantics
-            if ( $v =~ s/\A(['"])(.*)\1\z/$2/ && $1 eq '"' ) {
-                $v =~ s/\\n/\n/g;
-                $v =~ s/\\//g;
+            my $interpolate_vars = 1; # unquoted strings interpolate variables.
+
+            # drops quotes from quoted values, and interpolate if double quoted:
+            if ( $v =~ s/\A(['"])(.*)\1\z/$2/) {
+                if ($1 eq '"' ) {
+                    $v =~ s/\\n/\n/g;
+                    $v =~ s/\\//g;
+                }
+                else {
+                    $interpolate_vars = 0;
+                }
+            }
+
+            if ($interpolate_vars) {
+                # $env{$1} could point to a variable that doesn't exist.
+                no warnings 'uninitialized';
+                $v =~ s{\$($varname_re)}{exists $ENV{$1} ? $ENV{$1} : $env{$1}}ge;
             }
             $env{$k} = $v;
         }
@@ -110,7 +126,7 @@ ENV::Util - parse prefixed environment variables and dotnev (.env) files into Pe
 
 =head1 SYNOPSIS
 
-Efficiently load a '.env' file into %ENV:
+Efficiently load an L<'.env'|/"The .env file format"> file into %ENV:
 
     use ENV::Util -load_dotenv;
 
@@ -171,6 +187,43 @@ containers, we added a shortcut that loads it directly at compile time:
 
     use ENV::Util -load_dotenv;
 
+=head3 The .env file format
+
+Despite being almost ubiquitous in containerized environments, there is no
+standard format for "dotenv", and each implementation does its own thing.
+
+This is ours:
+
+    # comments can be standalone or inline.
+    # blank lines are also accepted.
+
+    # variable names must follow the pattern [A-Za-z_][a-zA-Z0-9_]+
+    # but usually are just A..Z in all caps.
+    FOO  =  some value   # spaces are trimmed except inside the string.
+    FOO='some value'     # so both lines here are the same.
+
+    NEWLINE=\n           # unquoted values are treated WITH interpolation.
+    NEWLINE="\n"         # so this line and the one above are the same.
+    LITERAL='\n'         # but this is a literal '\' and a literal 'n'.
+
+    BAR=baz          # bash/zsh format.
+    export BAR=baz   # bash format.
+    set BAR=baz      # tcsh/csh format.
+    setenv BAR baz   # tcsh/csh format (note this one lacks '=').
+
+    # empty values are set to the empty string ''
+    NONE =
+    ALSONONE
+
+    # you can prepend '$' to variable names to interpolate them
+    # in unquoted or double quoted values. You can point to variables
+    # declared before in the file or available in your %ENV
+    # *AS LONG AS* you don't try to replace variables from %ENV,
+    # which is not allowed by design.
+    MYKEY=$OTHERKEY
+    MYKEY=$MYKEY and something else  # ok to use the same variable.
+
+
 =head2 redacted_env()
 
 =head2 redacted_env( %options )
